Index: webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
diff --git a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
index befc619cb17285b90b5d8282ea64b3b2e241f177..d5aee967667e3abbbc426b5999cd6371dc8d4629 100644 |
--- a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
+++ b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
@@ -122,10 +122,9 @@ class ParsedRtcEventLog { |
// Only the fields that are stored in the protobuf will be written. |
void GetVideoSendConfig(size_t index, rtclog::StreamConfig* config) const; |
// Reads a config event to a (non-NULL) AudioReceiveStream::Config struct. |
// Only the fields that are stored in the protobuf will be written. |
- void GetAudioReceiveConfig(size_t index, |
- AudioReceiveStream::Config* config) const; |
+ void GetAudioReceiveConfig(size_t index, rtclog::StreamConfig* config) const; |
// Reads a config event to a (non-NULL) AudioSendStream::Config struct. |
// Only the fields that are stored in the protobuf will be written. |
@@ -122,10 +122,9 @@ class ParsedRtcEventLog { |
// Only the fields that are stored in the protobuf will be written. |
void GetVideoSendConfig(size_t index, rtclog::StreamConfig* config) const; |
- // Reads a config event to a (non-NULL) AudioReceiveStream::Config struct. |
+ // Reads a config event to a (non-NULL) StreamConfig struct. |
// Only the fields that are stored in the protobuf will be written. |